class KctGuidepostsController < ApplicationController
  before_action :set_guidepost, only: [:show, :edit, :update, :destroy]
  before_action :ensure_admin!

  def index
    @kct_guideposts = KctGuidepost.all
    # filtry
    @kct_guideposts = @kct_guideposts.where("CONCAT(kctref,LOWER(nazev)) LIKE ?", "%#{params[:search]}%") unless params[:search].blank?
    # paginace
    @kct_guideposts = @kct_guideposts.page(params[:page])
  end

  def show
   @guidepost = @kct_guidepost.guidepost
   @map_markers = []
   @map_markers += @kct_guidepost.kct_signs.select{|ks| ks.kct_trail.exist? and !ks.osm_trail.nil? }.
                     collect{|ks| ks.estimated_coordinates_from_osm + ["odhad dle #{ks.kct_trail.osm_trail.to_s}"]}
   @map_markers << @guidepost if !@guidepost.nil? and !@guidepost.lat.nil? and !@guidepost.lon.nil?
  end

  def new
    @kct_guidepost = KctGuidepost.new
  end

  def edit
  end

  def create
    @kct_guidepost = KctGuidepost.new(guidepost_params)

    respond_to do |format|
      if @kct_guidepost.save
        format.html { redirect_to @kct_guidepost, notice: 'KctGuidepost was successfully created.' }
        format.json { render action: 'show', status: :created, location: @kct_guidepost }
      else
        format.html { render action: 'new' }
        format.json { render json: "Nepodařilo se rozc. vytvořit(#{@kct_guidepost.errors})", status: :unprocessable_entity }
      end
    end
  end

  def update
    respond_to do |format|
      if @kct_guidepost.update(guidepost_params)
        format.html { redirect_to @kct_guidepost, notice: 'KctGuidepost was successfully updated.' }
        format.json { head :no_content }
      else
        format.html { render action: 'edit' }
        format.json { render json: @kct_guidepost.errors, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    @kct_guidepost.destroy
    respond_to do |format|
      format.html { redirect_to guideposts_url }
      format.json { head :no_content }
    end
  end

  private    
    # Use callbacks to share common setup or constraints between actions.
    def set_guidepost
      begin
        if params[:id].match /kctref-(..\d{3})/
          @kct_guidepost = KctGuidepost.find_by_kctref($1) # umožňuje použíte kctref-XXXX místo id v databázi
          raise "KČT rozcestník s kctref #{$1} není v databázi" if @kct_guidepost.nil?
        else  
          @kct_guidepost = KctGuidepost.find(params[:id])
        end
        
      rescue ActiveRecord::RecordNotFound
        flash.alert = "Tato OSM trasa není v databázi. Možná jde o starý odkaz a mezitím byla databáze reimportována."
        redirect_to :action=> :index
      end
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def guidepost_params
      params.require(:kct_guidepost).permit(:nazev, :kctref, :error)
    end
end
